Schema Docs

##

Type: object

##

Description for object_def/items/propertyA

Type: string

##

Description for array_def

Type: array of string

#### Each item of this array must be:

Type: string

##

Type: string

##

Description for string_def

Type: string

##

Type: object

##

Description for object_def/items/propertyA

Type: string

##

Type: string

##

The delivery is a gift, no prices displayed

Type: object

##

Type: boolean

##

The delivery is a gift, no prices displayed

Type: object

##

Type: boolean

##

The delivery is a gift, no prices displayed

Type: object

##

Type: boolean

##

Test schema with a not

Type: object

##

#### Must not be:

Type: string